<?php

/*
 *
 * Tutte le funzioni custom avranno prefisso
 * st (syrus theme) o syrus_theme nel nome
 *
 */

function get_syrus_theme_css_dir(){
  return SYRUS_THEME_URI.'/css/';
}

function get_syrus_theme_js_dir(){
  return SYRUS_THEME_URI.'/js/';
}

function get_syrus_theme_img_dir($img_name = ""){
  $default = SYRUS_THEME_URI.'/assets/img/';

  if(!$img_name)
    return $default;

  return $default.$img_name;
}

function st_get_enqueued_styles(){
  global $wp_styles;
  return $wp_styles;
}

function st_get_enqueued_scripts(){
  global $wp_scripts;
  return $wp_scripts;
}

function syrus_theme_register_css(){
  wp_register_style('bootstrap-css',get_syrus_theme_css_dir()."bootstrap.min.css",[],'5.0.2');
  wp_register_style('header-css',get_syrus_theme_css_dir()."header.css",[],'0.1.1');
  wp_register_style('post-css',get_syrus_theme_css_dir()."home-posts.css",[],'0.2.0');
  wp_register_style('single-post-css',get_syrus_theme_css_dir()."single-post.css",[],'0.1.7');
  wp_register_style('footer-css',get_syrus_theme_css_dir()."footer.css",[],'0.0.7');
  wp_register_style('sidebar-css',get_syrus_theme_css_dir()."sidebar.css",[],'0.0.6');
  wp_register_style('admin-css',get_syrus_theme_css_dir()."admin.css",['dashicons'],'0.1.2');
  return true;
}

function syrus_theme_enqueue_css(){
  wp_enqueue_style('bootstrap-css');
  wp_enqueue_style('header-css');
  wp_enqueue_style('footer-css');
  wp_enqueue_style('sidebar-css');
  return true;
}

function syrus_theme_admin_scripts(){
  global $pagenow;

  wp_enqueue_style('admin-css');
  wp_enqueue_script('custom-image-uploader-js');


  if($pagenow == "post-new.php" || $pagenow == "post.php") {
    wp_enqueue_script('admin-post-page-js');
  }

}

function get_js_infinite_scroll_version() {
  return "0.1.1";
}

function syrus_theme_register_js(){
  $_footer_js_version = "0.0.8";
  $_infinite_scroll_js_version = get_js_infinite_scroll_version();
  $_custom_image_uploader_js_version = "0.0.14";

  wp_register_script('bootstrap-js',get_syrus_theme_js_dir()."bootstrap.bundle.min.js",['jquery'],"5.0.2");
  wp_register_script('footer-js',get_syrus_theme_js_dir()."footer.js",['jquery'],$_footer_js_version);
  wp_localize_script('footer-js','args_footer',['current_version' => $_footer_js_version]);

  $blocchi = [syrus_theme_get_option('ads','post_blocco_1'),syrus_theme_get_option('ads','post_blocco_2'),syrus_theme_get_option('ads','post_blocco_3')];

  wp_register_script('options-ads-single-post-js',get_syrus_theme_js_dir()."options-ads-single-post.js",['jquery'],"0.0.3");
  wp_localize_script('options-ads-single-post-js','args_single_post',['blocchi' => $blocchi]);

  wp_register_script('infinite-scroll-js',get_syrus_theme_js_dir()."infinite-scroll.js",['jquery'],$_infinite_scroll_js_version);
  wp_localize_script('infinite-scroll-js','args_infinite_scroll',['current_version' => $_infinite_scroll_js_version,'ajax_url' => admin_url( 'admin-ajax.php' )]);


  wp_register_script('custom-image-uploader-js',get_syrus_theme_js_dir()."custom-image-uploader.js",['jquery'],$_custom_image_uploader_js_version);
  wp_localize_script('custom-image-uploader-js','args_uploader',['current_version' => $_custom_image_uploader_js_version,'can_user_upload' => current_user_can('syrus_theme_upload_files')]);

  wp_register_script('admin-post-page-js',get_syrus_theme_js_dir()."admin-post-page.js",['jquery'],"0.0.2");
}

function syrus_theme_enqueue_js(){
  wp_enqueue_script('bootstrap-js');
  wp_enqueue_script('footer-js');
}

function syrus_theme_after_load(){
  syrus_theme_aggiungi_supporto_per_customizer();
}

function syrus_theme_register_custom_menus(){
  register_nav_menus([
    'syrus-theme-main-menu' => __('Menu principale','syrus'),
  ]);
}

function st_has_nav_menu($menu){
  $menu_locations = get_nav_menu_locations();
  $menu_id = isset($menu_locations['syrus-theme-main-menu']) ? $menu_locations['syrus-theme-main-menu'] : 0;

  if($menu_id == 0)
    return false;
  
  return true;
}

function st_get_current_main_menu_name(){
  $menu_id = get_nav_menu_locations()['syrus-theme-main-menu'];
  return wp_get_nav_menu_object($menu_id)->name;
}

/* 
 *
 * Questa funzione viene eseguita per generare l'immagine di anteprima del post
 *  
 */
function syrus_theme_thumb_img($params = []){

  $img_size = isset($params["img_container_size"]) && $params["img_container_size"] == "12" ? "full" : "large";

  $img_container_col = isset($params["img_container_size"]) ? $params["img_container_size"] : "6";
  $img_col_order = isset($params['alternate']) && $params['alternate'] ? 2 : 1;

  $with_link = isset($params['with_link']) && $params['with_link'] ? true : false;
  $lazy_loadig = isset($params['lazy_loading']) && $params['lazy_loading'] ? true : false;

  if(!wp_is_mobile() && is_single()){
    $img_size = "full";
    $img_container_col = "12";
  }

  if(wp_is_mobile()){
    $img_size = "medium";
  }

  if(wp_is_mobile() && is_single()){
    $img_size = "large";
  }

  $args = [
    'img-size' => $img_size,
    'img-container-col' => $img_container_col,
    'img-col-order' => $img_col_order,
    'with_link' => $with_link,'lazy_loading' => $lazy_loadig
  ];
  
  
  get_template_part('template-parts/template-part','thumb-img',$args);
}


/* 
 *
 * Questa funzione viene eseguita per generare l'autore del post
 *  
 */
function syrus_theme_post_author(){ ?>

  <span class="news-author">
    <span class="news-author-by">By</span>
    <?php the_author(); ?>
  </span>
<?php }


/* 
 *
 * Questa funzione viene eseguita per generare le categorie del post
 *  
 */
function syrus_theme_post_category_list($no_link = true){
  $category_list = get_the_category_list(' ');
  $category_list_no_link = get_the_category();

  if($category_list && $category_list_no_link){ 

    // echo '<pre>';
    // print_r($category_list_no_link);
    // echo '</pre>';
    $kses_data = wp_kses_data($category_list);

    if($kses_data != "")
      $replace = str_replace('href','title="'.preg_replace('/<[^>]*>/', '',$kses_data).'" href',$kses_data); 

    if(is_category())
      $replace = $category_list_no_link[0]->name;
  ?>

    <div class="news-category <?php echo wp_is_mobile() ? 'is-mobile' : ''; ?>">
      <?php if(!$no_link) { ?>
        <?php echo $replace; ?>
      <?php } else { ?>
        <?php foreach($category_list_no_link as $cat) { ?> 
          <?php echo "<p>".$cat->name."</p>" ?>
        <?php } ?> 
      <?php } ?>
    </div>
    
  <?php }else{ ?>
    <br>
  <?php }

}


/**  
 * 
 * Questa funzione viene eseguita per generare una post singolo
 * 
 */
function syrus_theme_single_post(){

  wp_enqueue_style('single-post-css'); 

  $infinite_scroll = syrus_theme_get_option("generali","infinite_scroll");

  if($infinite_scroll && $infinite_scroll == 1)
    wp_enqueue_script('infinite-scroll-js');

  global $post;

  $tags = get_the_tag_list();
  
  wp_enqueue_script('options-ads-single-post-js');
  
  
  get_template_part('template-parts/template-part','single-post');

}

/**  
 * 
 * Questa funzione viene eseguita per generare i related posts
 * 
 */
function syrus_theme_related_posts(){
  global $post;
  
  $numero_di_post = 6;


  $post_tags = wp_get_post_tags(get_the_ID(),array(
    'orderby' => 'count',
    'order' => "ASC"
  ));

  $array_id_tags = array_map(function($item){
    return $item->term_id;
  },$post_tags);

  
  $related_posts = get_posts(array(
    'posts_per_page' => $numero_di_post,
    'exclude' => [get_the_ID()],
    'tag__in' => $array_id_tags,
    'orderby' => 'date',
    'order' => 'DESC',
    'date_query' => array(
      'before' => array(
        'year' => get_the_date('Y'),
        'month' => get_the_date('m'),
        'day' => get_the_date('d'),
        'hour' => get_the_date('H'),
        'minute' => get_the_date('i'),
      )
    )
  ));

  if(count($related_posts) == 0){
    $related_posts = get_posts([
      'posts_per_page' => $numero_di_post,
      'exclude' => [get_the_ID()],
      'orderby' => 'date',
      'order' => 'DESC',
      'date_query' => array(
        'before' => array(
          'year' => get_the_date('Y'),
          'month' => get_the_date('m'),
          'day' => get_the_date('d'),
          'hour' => get_the_date('H'),
          'minute' => get_the_date('i'),
        )
      )
    ]);
  }

  
  set_query_var('related_posts',$related_posts);
  get_template_part('template-parts/template-part','related-posts');
}

/**  
 * 
 * Questa funzione viene eseguita per generare una pagina singola
 * 
 */
function syrus_theme_single_page(){
  wp_enqueue_style('single-post-css'); 
  get_template_part('template-parts/template-part','single-page');
}

/* 
 *
 * Questa funzione viene eseguita per generare la home
 *  
 */
function syrus_theme_home(){

  wp_enqueue_style('post-css'); 

  $current_page = get_query_var('paged');
  $category = get_query_var('cat');
  $search = get_query_var('s');

  if($current_page == 0)
    $current_page = 1;

  $args = array(
    'paged' => $current_page,
    'posts_per_page' => get_option('posts_per_page') ?: 10,
    'ignore_sticky_posts' => 1,
    'post_type' => "post",
    'post_status' => "publish" 
    );
 
  if($category)
    $args['cat'] = $category;

  if($search)
    $args['s'] = $search;

  $the_query = new WP_Query( $args );
  set_query_var('the_query',$the_query);
  $_infinite_scroll_js_version = get_js_infinite_scroll_version();

  if(syrus_theme_get_option("generali","infinite_scroll_home") == 1 && is_home()) {
    wp_localize_script('infinite-scroll-js','args_infinite_scroll',['current_version' => $_infinite_scroll_js_version,'ajax_url' => admin_url( 'admin-ajax.php' ),'home_page' => 1]);
    wp_enqueue_script('infinite-scroll-js');
  }

  get_template_part('template-parts/template-part','home',$args);
}

/* 
 *
 * Questa funzione viene eseguita per generare la pagina 404
 *  
 */
function syrus_theme_error_404(){
  wp_enqueue_style('single-post-css'); 
  get_template_part('template-parts/template-part','error-404');
}


function syrus_theme_footer(){
  get_template_part('template-parts/template-part','footer');
}


function syrus_theme_post_excerpt(){
  $parole_da_mostrare = 20;
  $p = get_post();
  $excerpt = wp_trim_words($p->post_content,$parole_da_mostrare); ?>

  <p class="news-excerpt"><?php echo $excerpt; ?></p>

<?php }

function st_get_network_syrus_sites (){
  $sites = [
    (object) array(
      'domain' => "syrus.blog",
      'lang' => "it",
      'country' => "Italy"
    ),
    (object) array(
      'domain' => "syrus.today",
      'lang' => "us",
      'country' => "United States",
    ),
    (object) array(
      'domain' => "syrus.dev",
      'lang' => "fr",
      'country' => "France",
    ),
    (object) array(
      'domain' => "syrus.es",
      'lang' => "es",
      'country' => "Spain",
    ),
    (object) array(
      'domain' => "syrus.com.br",
      'lang' => "br",
      'country' => "Brazil",
    ),
    (object) array(
      'domain' => "syrus.jp",
      'lang' => "jp",
      'country' => "Japan",
    ),
    (object) array(
      'domain' => "syrus.com.ru",
      'lang' => "ru",
      'country' => "Russia",
    ),
    (object) array(
      'domain' => "syrus.ae",
      'lang' => "ae",
      'country' => "United Arab Emirates",
    ),
    (object) array(
      'domain' => "syrus.online",
      'lang' => "de",
      'country' => "Germany",
    ),
  ];

  return $sites;
}

function syrus_theme_get_categories_for_sidebar(){
  $cats = get_categories();
  $to_return = [];

  foreach($cats as $cat){
    $n_post = count(get_posts([
      'numberposts' => 10,
      'category' => $cat->term_id
    ]));

    if($n_post == 10)
      $to_return[] = $cat;
  }

  return $to_return;
}

function syrus_theme_get_template_parts_admin($file = ""){

  if($file == "")
    return null;

  return SYRUS_THEME_PATH."/template-parts/wp-admin/".$file.".php";
}

function syrus_theme_add_admin_post_action(){
  add_action('admin_post_salva_impostazioni_ads',"syrus_theme_salva_impostazioni_ads");
  add_action('admin_post_salva_robots_ads_txt',"syrus_theme_salva_robots_ads_txt");
  add_action('admin_post_salva_impostazioni_generali',"syrus_theme_salva_impostazioni_generali");
  add_action('admin_post_salva_impostazioni_cap_media',"syrus_theme_salva_impostazioni_cap_media");
  add_action('admin_post_salva_impostazioni_social',"syrus_theme_salva_impostazioni_social");

  add_action('admin_post_export-impostazioni-tema',"syrus_theme_export_impostazioni_tema");
  add_action('admin_post_import-impostazioni-tema',"syrus_theme_import_impostazioni_tema");

  add_action('admin_post_dismiss-notice-syrus',"syrus_theme_dismiss_notice");

}

function syrus_theme_add_ajax_post_action(){
  add_action( 'wp_ajax_infinite-scroll-new-post','syrus_theme_infinite_scroll_new_post');
  add_action( 'wp_ajax_nopriv_infinite-scroll-new-post','syrus_theme_infinite_scroll_new_post');

  add_action( 'wp_ajax_infinite-scroll-new-posts-in-home','syrus_theme_infinite_scroll_new_posts_in_home');
  add_action( 'wp_ajax_nopriv_infinite-scroll-new-posts-in-home','syrus_theme_infinite_scroll_new_posts_in_home');
}

function syrus_theme_show_virtual_ads_txt(){
  if(syrus_theme_get_option("file",'abilita_ads_txt') != 1)
    return true;

  $ads_txt = syrus_theme_get_option("file","ads_txt");
  echo $ads_txt;
  header('Content-type: text/plain');
  header('Content-disposition: inline');
  status_header(200);
}

function syrus_theme_show_virtual_robots_txt($output, $public){

  if(syrus_theme_get_option("file",'abilita_robots_txt') != 1)
    return $output;


  $robots_txt = syrus_theme_get_option("file","robots_txt");
  return $robots_txt;
}

function syrus_theme_infinite_scroll_new_posts_in_home() {
  $page = $_POST['page'];
  $current_page = $page + 1;
  set_query_var('paged',$current_page);

  $args = [
    'paged' => $current_page,
    'posts_per_page' => get_option('posts_per_page') ?: 10,
    'ignore_sticky_posts' => 1,
    'post_type' => "post",
    'post_status' => "publish",
    'is_ajax' => true,
  ];

  $the_query = new WP_Query( $args );
  set_query_var('the_query',$the_query);

  $path = SYRUS_THEME_PATH."/template-parts/template-part-home.php";
  $html = syrus_theme_includi($path,compact('the_query','args'));
  $post_finiti = !$the_query->have_posts() ? true : false;

  wp_send_json_success(['html' => $html,'post_finiti' => $post_finiti]);
}

function syrus_theme_infinite_scroll_new_post(){
  $id_ultimo_articolo = $_POST['ultimo_articolo'];
  $id_articoli_presenti = $_POST['id_articoli']; 

  $ultimo_post = get_post($id_ultimo_articolo);

  $post = get_posts(array(
    'posts_per_page' => 1,
    'orderby' => 'date',
    'order' => "DESC",
    'exclude' => $id_articoli_presenti,
  ));

  if(!isset($post[0]))
    wp_send_json_error("Nessun post");

  $ajax_post = $post[0];

  global $post;
  $post = $ajax_post;
  setup_postdata($post);

  $path = SYRUS_THEME_PATH."/template-parts/template-part-single-post.php";
  $html = syrus_theme_includi($path,compact('ajax_post'));
  wp_send_json_success($html);
}

function syrus_theme_includi($percorso_file, $variabili = array(), $stampa = false){
    $output = NULL;
    if(file_exists($percorso_file)){
        extract($variabili);
        ob_start();
        include $percorso_file;
        $output = ob_get_clean();
    }
    if ($stampa) {
        print $output;
    }
    return $output;

}


function syrus_theme_query_vars($query_vars){
  $query_vars[] = "related_posts";
  return $query_vars;
}



function syrus_theme_messaggio_plugin_necessari(){

  if(get_option('syrus_theme_notice_dismiss') == 1)
    return "";

  $required_plugins = [
    [
      'name' => "Content Security Policy Manager",
      'shortname' => "CSP Manager",
      'download_link' => "//wordpress.org/plugins/csp-manager/",
      'required_file' => "csp-manager/csp-manager.php",
    ],
    [
      'name' => "Head, Footer and Post Injections",
      'shortname' => "Head, Footer and Post Injections",
      'download_link' => "//wordpress.org/plugins/header-footer/",
      'required_file' => "header-footer/plugin.php",
    ],
    [
      'name' => "Yoast SEO",
      'shortname' => "Yoast SEO",
      'download_link' => "//wordpress.org/plugins/wordpress-seo/",
      'required_file' => "wordpress-seo/wp-seo.php" 
    ],
    [
      'name' => "Site Kit by Google – Analytics, Search Console, AdSense, Speed",
      'shortname' => "Site Kit by Google",
      'download_link' => "//wordpress.org/plugins/google-site-kit/",
      'required_file' => "google-site-kit/google-site-kit.php"
    ],
    [
      'name' => "Jetpack: sicurezza, backup, velocità e crescita di WP",
      'shortname' => "Jetpack",
      'download_link' => "//wordpress.org/plugins/jetpack/",
      'required_file' => "jetpack/jetpack.php"
    ],
    [
      'name' => "Instant Images – One Click Unsplash, Pixabay and Pexels Uploads",
      'shortname' => "Instant Images",
      'download_link' => "//wordpress.org/plugins/instant-images/",
      'required_file' => "instant-images/instant-images.php"
    ],
    [
      'name' => "Scheduled Post Trigger",
      'shortname' => "Scheduled Post Trigger",
      'download_link' => "//wordpress.org/plugins/scheduled-post-trigger/",
      'required_file' => "scheduled-post-trigger/scheduled-post-trigger.php"
    ],
    [
      'name' => "IndexNow Plugin",
      'shortname' => "IndexNow",
      'download_link' => "//wordpress.org/plugins/indexnow/",
      'required_file' => "indexnow/indexnow-url-submission.php"
    ],
  ];

  $testo = '<div data-dismissible="syrus-theme-notice" class="notice notice-warning syrus-theme-notice is-dismissible">
              <h6 style="margin-top:.5em">Plugin consigliati per il corretto funzionamento del tema:</h6>
  ';

  $i = 0;

  foreach($required_plugins as $plugin){
    if(is_plugin_active($plugin['required_file']))
      continue;

    $testo .= '<p><a href="'.$plugin['download_link'].'" target="_blank"><b>'.$plugin['shortname'].'</b> ('.$plugin['name'].')</a></p>';
    $i++;
  }

  $testo .= '<form action="'. admin_url('admin-post.php') .'" method="POST"><input type="hidden" name="action" value="dismiss-notice-syrus"><button class="btn-not-show-again">'."Dont'show again!".'</button></form>';
  $testo .= '</div>';

  if($i > 0)
    echo $testo;


  return true;

}

function syrus_theme_preload_resources(){
  $current_page = get_query_var('paged');
  global $wp_query;
  
  if($current_page == 0)
    $current_page = 1;

  $resource_to_preload = [
    ['type' => "font",'href' =>  SYRUS_THEME_URI.'/fonts/Montserrat-Regular.ttf']
  ];

  if(is_home()){
    $img_size = wp_is_mobile() ? "medium" : "large";

    $posts = get_posts($args = array(
      'paged' => $current_page,
      'posts_per_page' => 10,
      'ignore_sticky_posts' => 1,
      'post_type' => "post",
      'post_status' => "publish" 
    ));

    foreach($posts as $p){
      $img_href = get_the_post_thumbnail_url($p->ID,$img_size);

      if(!$img_href)
          continue;

      $resource_to_preload[] = ['type' => "image",'href' => get_the_post_thumbnail_url($p->ID,$img_size)];
    }

    $resource_to_preload[] = ['type' => "image",'href' => get_the_post_thumbnail_url($wp_query->posts[0]->ID,$img_size)];
  }

  if(is_single()){
    $img_size = wp_is_mobile() ? "large" : "full";
    $resource_to_preload[] = ['type' => "image",'href' => get_the_post_thumbnail_url(get_the_ID(),$img_size)];
  }

  if(is_category()){
    echo '<!-- PRELOAD CATEGORY -->';
  }

  if(is_search()){
    echo '<!-- PRELOAD SEARCH -->';
  }

  foreach($resource_to_preload as $res){
    echo '<link rel="preload" as="'.$res['type'].'" href="'.$res['href'].'"  crossorigin="anonymous">';
  }
}


function syrus_theme_topnav(){
  $args = [
    'bg_color_after_main_menu' => sanitize_text_field(get_theme_mod('bg-color-after-main-menu','orange')) ?: 'orange',
    'background_color_motto' => sanitize_text_field(get_theme_mod('background-color-motto','#e5e8ef')) ?: '#e5e8ef',
    'text_color_motto' => sanitize_text_field(get_theme_mod('text-color-motto','#000000')) ?: '#000000',
    'set_motto' => sanitize_text_field(get_bloginfo('description')),
    'bg_color_logo' => sanitize_text_field(get_theme_mod('bg-color-logo','#fff')) ?: "#fff",
    'set_image' => syrus_theme_get_custom_logo_url(),
    'bg_color_main_menu' => sanitize_text_field(get_theme_mod('bg-color-main-menu','#333743')) ?: '#333743',
    'main_menu_img' => sanitize_text_field(get_theme_mod('custom_logo')) ? wp_get_attachment_image_src( sanitize_text_field(get_theme_mod('custom_logo')) , 'full' )[0] : null,
    'text_color_main_menu' => sanitize_text_field(get_theme_mod('text-color-main-menu','#cedce9')) ?: '#cedce9',
  ];

  get_template_part('template-parts/template-part','topnav',$args);
}


function syrus_theme_get_custom_logo_url() {
  return get_header_image() ?: get_syrus_theme_img_dir('blog-header.png');
}

function syrus_theme_replace_span_tags($text){

  if(!$text)
    return $text;

  $span_replace_chk = syrus_theme_get_option("generali","span_replace");
  $p_cleaner_chk = syrus_theme_get_option("generali","p_cleaner");

  // HTTP => HTTPS
  $text = str_replace('http://','https://',$text);

  $encoding = mb_detect_encoding($text);

  $text = mb_convert_encoding($text, 'HTML-ENTITIES', 'UTF-8');

  $html = new DOMDocument();
  @$html->loadHTML('<div>'.$text.'</div>', LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);
  
  // Rimozione degli attributi nei tag p
  $ptag = $html->getElementsByTagName('p');

  $span_tags = $html->getElementsByTagName('span');

  if($span_replace_chk) {
    foreach($span_tags as $span){
      $span->removeAttribute('style');
      $span->removeAttribute('class');
      $span->removeAttribute('data-contrast');
      $span->removeAttribute('data-ccp-props');
    }
  }


  if($p_cleaner_chk) {
    foreach($ptag as $p) {
        $p->removeAttribute('style');
    }
  }

  $root = $html->documentElement;

  $result = "";


  foreach($root->childNodes as $child) {
    $result .= $html->saveHTML($child);
  }

  $text = $result;

  if($span_replace_chk){
    $text = str_replace('<span>','',$text);
    $text = str_replace('</span>','',$text);
  }

	return $text;
}

function syrus_theme_add_post_submitbox_misc_actions($post) { 
  
  $errori_seo = get_post_meta($post->ID,'syrus_theme_errori_seo',true);
  ?>

  <?php if($errori_seo) { ?>
    <div class="misc-pub-section misc-pub-errori-seo">
      <u><?php _e("Found SEO errors",'syrus') ?>:</u>
      <ul class="ps-2">
        <?php foreach(explode(',',$errori_seo) as $i => $errore) { ?>
          <li>
            <?php
             switch($errore) {
              case 'tag-h1-presente':
                echo ($i + 1).") <b>".__("H1 tag must not be present",'syrus')."</b>";
                break;
              case 'tag-h2-non-presente':
                echo ($i + 1).") <b>".__("There must be at least 1 H2 tag",'syrus')."</b>";
                break;
              case 'tag-h3-non-presente':
                echo ($i + 1).") <b>".__("There must be at least 1 H3 tag",'syrus')."</b>";
                break;
              case 'tag-strong-non-presente':
                echo ($i + 1).") <b>".__("There must be at least 2 strong tags",'syrus')."</b>";
                break;
              case 'tag-strong-presente-piu-di-8':
                echo ($i + 1).") <b>".__("There must be at most 8 strong tags",'syrus')."</b>";
                break;
              case 'tag-p-non-presente':
                echo ($i + 1).") <b>".__("There must be at least 3 paragraphs",'syrus')."</b>";
                break;
              case 'tag-h2-uguale-al-titolo':
                echo ($i + 1).") <b>".__("The text where there are H2 tags cannot be the same as the title",'syrus')."</b>";
                break;
              case 'tag-h2-e-h3-duplicato':
                echo ($i + 1).") <b>".__("The text where there are H3 tags cannot be the same as the text in which there are H2 tags",'syrus')."</b>";
                break;
              case 'min-500-parole':
                echo ($i + 1).") <b>".__("Must have at least of 500 words",'syrus')."</b>";
                break;
              case 'min-2-link-interni':
                echo ($i + 1).") <b>".__("Must have at least of 2 internal links",'syrus')."</b>";
                break;
              case 'max-1-link-esterno':
                echo ($i + 1).") <b>".__("Must have at most 1 external link",'syrus')."</b>";
                break;
              case 'max-5-words-min-3-words-per-link':
                echo ($i + 1).") <b>".__("Each link inserted must have a minimum of 3 words and a maximum of 5",'syrus')."</b>";
                break;
              case 'immagine-in-evidenza-non-presente':
                echo ($i + 1).") <b>".__("The post must have a thumbnail",'syrus')."</b>";
                break;
             }

            ?>
          </li>
        <?php } ?>
      </ul>
      <i><?php _e("It will not be possible to make the post public until the errors are resolved!",'syrus') ?></i>
    </div>
  <?php } ?>

<?php }


function syrus_theme_check_post($post_id,$post) {
  $errori_trovati = [];
  $hide_post = false;
  update_post_meta($post_id,'syrus_theme_errori_seo',null);

  if(current_user_can('manage_options'))
    return true;
  
  if($post->post_status != "publish" && $post->post_status != "draft")
    return true;

  $text = mb_convert_encoding($post->post_content, 'HTML-ENTITIES', 'UTF-8');
  $html = new DOMDocument();
  @$html->loadHTML('<div>'.$text.'</div>', LIBXML_HTML_NOIMPLIED | LIBXML_HTML_NODEFDTD);

  $strong_elements = $html->getElementsByTagName('strong');
  $h1_elements = $html->getElementsByTagName('h1');
  $h2_elements = $html->getElementsByTagName('h2');
  $h3_elements = $html->getElementsByTagName('h3');
  $p_elements = $html->getElementsByTagName('p');
  $a_elements = $html->getElementsByTagName('a');

  if($h1_elements->length > 0){
    $errori_trovati[] = "tag-h1-presente";
    $hide_post = true;
  }

  if($h2_elements->length < 1){
    $errori_trovati[] = "tag-h2-non-presente";
    $hide_post = true;
  }

  if($h3_elements->length < 1){
    $errori_trovati[] = "tag-h3-non-presente";
    $hide_post = true;
  }

  if($strong_elements->length < 2) {
    $errori_trovati[] = "tag-strong-non-presente";
    $hide_post = true;
  }

  if($strong_elements->length > 8) {
    $errori_trovati[] = "tag-strong-presente-piu-di-8";
    $hide_post = true;
  }

  if($p_elements->length < 3) {
    $errori_trovati[] = "tag-p-non-presente";
    $hide_post = true;
  }

  $testi_h2 = [];

  foreach($h2_elements as $h2tag) {
    $testi_h2[] = strtolower($h2tag->nodeValue);
  }

  if(in_array(strtolower($post->post_title),$testi_h2)) {
    $errori_trovati[] = "tag-h2-uguale-al-titolo";
    $hide_post = true;
  }

  $testi_h3 = [];

  foreach($h3_elements as $h3tag) {
    $testi_h3[] = strtolower($h3tag->nodeValue);
  }

  $alert_h3_h2 = false;

  foreach($testi_h2 as $th2) {
    if(in_array($th2,$testi_h3))
      $alert_h3_h2 = true;
  }

  if($alert_h3_h2) {
    $errori_trovati[] = "tag-h2-e-h3-duplicato";
    $hide_post = true;
  }

  $clean_content = trim(strip_tags($post->post_content));
  $parole = count(explode(" ", $clean_content));

  if($parole < 501) {
    $errori_trovati[] = "min-500-parole";
    $hide_post = true;
  }

  $link_interni = 0;
  $link_esterni = 0;
  $link_non_validi = 0;

  foreach($a_elements as $a_tag) {
    $href = $a_tag->getAttribute('href');
    $testo = $a_tag->nodeValue; 
    $parole_testo = explode(' ',$testo);

    if(count($parole_testo) < 3 || count($parole_testo) > 5)
      $link_non_validi++;

    // se non contiene http/https allora do per scontanto che sia link interno
    if(strpos($href,'http://') === false && strpos($href,'https://') === false) {
      $link_interni++;
      continue;
    }

    if(strpos($href,home_url()) !== false) {
      $link_interni++;
      continue;
    }

    $link_esterni++;
  }

  if($link_interni < 2) {
    $errori_trovati[] = "min-2-link-interni";
    $hide_post = true;
  }

  if($link_esterni > 1) {
    $errori_trovati[] = "max-1-link-esterno";
    $hide_post = true;
  }

  if($link_non_validi > 0) {
    $errori_trovati[] = "max-5-words-min-3-words-per-link";
    $hide_post = true;
  }

  if(!has_post_thumbnail($post_id)) {
    $errori_trovati[] = "immagine-in-evidenza-non-presente";
    $hide_post = true;
  }

  $_errori_trovati = [];
  $controlli_seo_abilitati = explode(',',syrus_theme_get_option("generali","controlli_seo"));

  foreach($errori_trovati as $err) {
    if(in_array($err,$controlli_seo_abilitati))
      $_errori_trovati[] = $err;
  }

  $errori_trovati = $_errori_trovati;

  if($hide_post && count($errori_trovati) > 0) {
    wp_update_post([
      'ID' => $post_id,
      'post_status' => "pending"
    ]);
  }

  update_post_meta($post_id,'syrus_theme_errori_seo',implode(',',$errori_trovati));

}

function syrus_theme_dismiss_notice() {
  update_option('syrus_theme_notice_dismiss',1);
  wp_safe_redirect($_SERVER['HTTP_REFERER']);
}


function syrus_theme_make_WordPress_Happy() {
  add_editor_style();

  comments_template();

  comment_form();

  register_block_style();

  register_block_pattern();

  paginate_comments_links();

  wp_enqueue_script('comment-reply');
}

